@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.83';
+our $VERSION = '0.84';
 
 use Dist::Zilla 6.0;
 
@@ -452,7 +452,7 @@ sub _meta_plugins {
             MetaConfig
             MetaJSON
             MetaYAML
-            ),
+        ),
     );
 }
 
@@ -571,12 +571,11 @@ sub _prompt_if_stale_plugin {
                     qw(
                         Dist::Zilla::Plugin::MAXMIND::CheckChangesHasContent
                         Dist::Zilla::Plugin::MAXMIND::Contributors
-                        Dist::Zilla::Plugin::MAXMIND::Git::CheckFor::CorrectBranch
                         Dist::Zilla::Plugin::MAXMIND::License
                         Dist::Zilla::Plugin::MAXMIND::TidyAll
                         Dist::Zilla::Plugin::MAXMIND::VersionProvider
                         Pod::Weaver::PluginBundle::MAXMIND
-                        )
+                    )
                 ],
             }
         ],
@@ -661,7 +660,7 @@ sub _extra_test_plugins {
             Test::NoTabs
             Test::Portability
             Test::Synopsis
-            ),
+        ),
         [
             'Test::TidyAll' => {
                 verbose => 1,
@@ -732,9 +731,8 @@ sub _release_check_plugins {
             CheckSelfDependency
             CheckPrereqsIndexed
             MAXMIND::CheckChangesHasContent
-            MAXMIND::Git::CheckFor::CorrectBranch
             Git::CheckFor::MergeConflicts
-            ),
+        ),
     );
 }
 
@@ -768,7 +766,7 @@ sub _git_plugins {
         qw(
             Git::Tag
             Git::Push
-            ),
+        ),
 
         # Bump all module versions.
         'BumpVersionAfterRelease',
@@ -796,7 +794,7 @@ sub _build_allow_dirty {
         qw(
             Changes
             tidyall.ini
-            )
+        )
     ];
 }
 
@@ -818,7 +816,7 @@ Dist::Zilla::PluginBundle::MAXMIND - MAXMIND's plugin bundle
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
 =head1 SYNOPSIS
 
@@ -968,7 +966,6 @@ This is more or less equivalent to the following F<dist.ini>:
     check_authordeps  = 1
     skip = Dist::Zilla::Plugin::MAXMIND::CheckChangesHasContent
     skip = Dist::Zilla::Plugin::MAXMIND::Contributors
-    skip = Dist::Zilla::Plugin::MAXMIND::Git::CheckFor::CorrectBranch
     skip = Dist::Zilla::Plugin::MAXMIND::License
     skip = Dist::Zilla::Plugin::MAXMIND::TidyAll
     skip = Dist::Zilla::Plugin::MAXMIND::VersionProvider
@@ -1054,11 +1051,6 @@ This is more or less equivalent to the following F<dist.ini>:
     ; CPAN::Changes to parse the Changes file.
     [MAXMIND::CheckChangesHasContent]
 
-    ; Just like Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch except that
-    ; it allows releases from any branch for TRIAL
-    ; releases. https://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor/issues/24
-    [MAXMIND::Git::CheckFor::CorrectBranch]
-
     [Git::CheckFor::MergeConflicts]
 
     ; Generates/updates tidyall.ini, perlcriticrc, and perltidyrc
@@ -1104,7 +1096,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dave Rolsky Greg Oschwald Mark Fowler Olaf Alders Patrick Cronin
+=for stopwords Dave Rolsky Florian Ragwitz Greg Oschwald Mark Fowler Olaf Alders Patrick Cronin Will Storey
 
 =over 4
 
@@ -1114,6 +1106,10 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =item *
 
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
 Greg Oschwald <goschwald@maxmind.com>
 
 =item *
@@ -1132,11 +1128,15 @@ Patrick Cronin <PatrickCronin@users.noreply.github.com>
 
 Patrick Cronin <pcronin@maxmind.com>
 
+=item *
+
+Will Storey <wstorey@maxmind.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Dave Rolsky and MaxMind, Inc.
+This software is Copyright (c) 2021 by Dave Rolsky and MaxMind, Inc.
 
 This is free software, licensed under:
 
